The Timelink python package
---------------------------

The Timelink python package can be used to:

* Create and access Timelink/MHK databases from python code.
* Create Kleio source data and store it the database.
* Import data generated by the Kleio translator

The package includes:

* Pythonic representation of Kleio groups, easing generation of Kleio
  file from data in other formats.
* ORM models for the Timelink database
* Utility functions for acessing a Timelink/MHK instalation.
* CLI tool.

See: https://timelink-py.readthedocs.io/